Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EstimationReport ¶
type EstimationReport struct {
Resource resources.GenericResource
Power decimal.Decimal `json:"PowerPerInstance"`
CarbonEmissions decimal.Decimal `json:"CarbonEmissionsPerInstance"`
AverageCPUUsage decimal.Decimal
Count decimal.Decimal
}
EstimationReport is the struct that contains the estimation of a resource
func GetEstimation ¶
func GetEstimation(resource resources.GenericResource) (EstimationReport, error)
GetEstimation returns the estimation of a resource
func GetEstimationFromInstanceType ¶
func GetEstimationFromInstanceType(instanceType string, zone string, provider providers.Provider) (EstimationReport, error)
GetEstimationFromInstanceType returns the estimation of a resource from its instance type
Click to show internal directories.
Click to hide internal directories.